<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>U2::ChromaViewAction</name>
    <message>
        <location filename="../src/ChromaViewPlugin.cpp" line="109"/>
        <source>show_chromatogram</source>
        <translation>Показать хроматограмму</translation>
    </message>
</context>
<context>
    <name>U2::ChromaViewPlugin</name>
    <message>
        <location filename="../src/ChromaViewPlugin.cpp" line="33"/>
        <source>chroma_view_plugin_desc</source>
        <translation>Визуализация и редактирование хроматограмм</translation>
    </message>
    <message>
        <location filename="../src/ChromaViewPlugin.cpp" line="33"/>
        <source>ChromaView</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::ChromatogramView</name>
    <message>
        <location filename="../src/ChromatogramView.cpp" line="70"/>
        <source>add_new_seq</source>
        <translation>Редактировать новую последовательность</translation>
    </message>
    <message>
        <location filename="../src/ChromatogramView.cpp" line="73"/>
        <source>add_exist_seq</source>
        <translation>Редактировать существующую последовательность</translation>
    </message>
    <message>
        <location filename="../src/ChromatogramView.cpp" line="76"/>
        <source>remove_editable_sequence</source>
        <translation>Удалить редактируемую последовательность</translation>
    </message>
    <message>
        <location filename="../src/ChromatogramView.cpp" line="79"/>
        <source>remove_changes</source>
        <translation>Отменить изменения</translation>
    </message>
    <message>
        <location filename="../src/ChromatogramView.cpp" line="161"/>
        <location filename="../src/ChromatogramView.cpp" line="274"/>
        <source>error</source>
        <translation>Внимание</translation>
    </message>
    <message>
        <location filename="../src/ChromatogramView.cpp" line="161"/>
        <location filename="../src/ChromatogramView.cpp" line="274"/>
        <source>sequence_object_was_locked</source>
        <translation>Последовательность заблокирована</translation>
    </message>
    <message>
        <location filename="../src/ChromatogramView.cpp" line="42"/>
        <source>Show quality bars</source>
        <translation>Показывать уровни достоверности</translation>
    </message>
</context>
<context>
    <name>U2::ChromatogramViewRenderArea</name>
    <message>
        <location filename="../src/ChromatogramView.cpp" line="389"/>
        <source>selection_is_too_big</source>
        <translation>Хроматограмма (приближайте масштаб)</translation>
    </message>
    <message>
        <location filename="../src/ChromatogramView.cpp" line="601"/>
        <source>original</source>
        <translation>Исходная последовательность</translation>
    </message>
</context>
</TS>
